@@ -4,9 +4,10 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "config-itinerary.h"
 #include "settings.h"
 
-#include <KContacts/Address>
+#include <KCountry>
 
 #include <QDebug>
 #include <QLocale>
@@ -19,13 +20,15 @@ Settings::Settings(QObject *parent)
     s.beginGroup(QLatin1String("Settings"));
     m_weatherEnabled = s.value(QLatin1String("WeatherForecastEnabled"), false).toBool();
 
-    const auto currentCountry = KContacts::Address::countryToISO(QLocale::countryToString(QLocale().country())).toUpper();
+    const auto currentCountry = KCountry::fromQLocale(QLocale().country()).alpha2();
     m_homeCountry = s.value(QLatin1String("HomeCountry"), currentCountry).toString();
 
     m_queryLiveData = s.value(QLatin1String("QueryLiveData"), false).toBool();
 
     m_preloadMapData = s.value(QLatin1String("PreloadMapData"), false).toBool();
 
+    m_currencyConversion = s.value(QLatin1String("PerformCurrencyConversion"), false).toBool();
+
     m_autoAddTransfers = s.value(QLatin1String("AutoAddTransfers"), true).toBool();
     m_autoFillTransfers = s.value(QLatin1String("AutoFillTransfers"), false).toBool() && m_queryLiveData && m_autoAddTransfers;
 
@@ -36,6 +39,18 @@ Settings::Settings(QObject *parent)
 
 Settings::~Settings() = default;
 
+QVariant Settings::read(const QString &key, const QVariant &defaultValue) const
+{
+    QSettings s;
+    return s.value(key, defaultValue);
+}
+
+void Settings::write(const QString& key, const QVariant& value)
+{
+    QSettings s;
+    s.setValue(key, value);
+}
+
 bool Settings::weatherForecastEnabled() const
 {
     return m_weatherEnabled;
@@ -116,6 +131,34 @@ void Settings::setPreloadMapData(bool preload)
     Q_EMIT preloadMapDataChanged(preload);
 }
 
+bool Settings::hasCurrencyConversion() const
+{
+#if HAVE_KUNITCONVERSION
+    return true;
+#else
+    return false;
+#endif
+}
+
+bool Settings::performCurrencyConversion() const
+{
+    return m_currencyConversion;
+}
+
+void Settings::setPerformCurrencyConversion(bool enable)
+{
+    if (m_currencyConversion == enable) {
+        return;
+    }
+
+    m_currencyConversion = enable;
+    QSettings s;
+    s.beginGroup(QLatin1String("Settings"));
+    s.setValue(QLatin1String("PerformCurrencyConversion"), enable);
+
+    Q_EMIT performCurrencyConversionChanged(enable);
+}
+
 bool Settings::autoAddTransfers() const
 {
     return m_autoAddTransfers;
