@@ -15,8 +15,6 @@
 #include <KAndroidExtras/JavaTypes>
 #include <KAndroidExtras/Uri>
 
-#include <QAndroidJniObject>
-
 class QUrl;
 
 namespace KAndroidExtras {
@@ -30,9 +28,7 @@ class KANDROIDEXTRAS_EXPORT Intent
     JNI_OBJECT(Intent, android::content::Intent)
 public:
     /** Creates a new empty intent. */
-    Intent();
-    /** Adopts an existing intent available as a JNI object. */
-    explicit Intent(const QAndroidJniObject &intent);
+    JNI_CONSTRUCTOR(Intent)
     ~Intent();
 
     /** Add a category to the intent. */
@@ -60,12 +56,11 @@ public:
     template <typename T>
     inline void putExtra(const QAndroidJniObject &name, const QAndroidJniObject &value)
     {
-        m_intent.callObjectMethod("putExtra", Jni::signature<android::content::Intent(java::lang::String, T)>(), name.object(), value.object());
+        jniHandle().callObjectMethod("putExtra", Jni::signature<android::content::Intent(java::lang::String, T)>(), name.object(), value.object());
     }
 
     /** Implicit conversion to an QAndroidJniObject. */
     operator QAndroidJniObject() const;
-    QAndroidJniObject handle() const;
 
     /** Action constant for create document intents. */
     JNI_CONSTANT(java::lang::String, ACTION_CREATE_DOCUMENT)
@@ -96,7 +91,6 @@ public:
 private:
     template <typename T>
     QAndroidJniObject getObjectExtra(const char* methodName, const QAndroidJniObject &name) const;
-    QAndroidJniObject m_intent;
 };
 
 }
